.dialog-shadow {
	content: '';
	position: fixed;
	width: 100%;
	height: 100%;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	background-color: #fff;
	opacity: .5;
	display: none;
}

dialog {
	position: fixed;
	max-width: 600px;
	width: auto;
	top: 100px;
	left: 50%;
	margin-left: -300px;

	border-radius: 5px;
	border: none;
	box-shadow: 0px 0px 15px 0px rgba(0,0,0,0.5);
}

body:not([data-member-dialog='none']) dialog,
body:not([data-member-dialog='none']) .dialog-shadow {
	display: block;
}

dialog div[data-member-id] {
	display: none;
}

dialog div[data-member-id].show {
	display: block;
}


@media (max-width: 700px) {
	dialog {
		max-width: auto;
        left: 15px;
        right: 15px;
        top: 44px;
        margin-left: 0;
    }
}
